@@ -1,22 +1,22 @@
-# Copyright (C) 2007 Michael Creel <michael.creel@uab.es>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; If not, see <http://www.gnu.org/licenses/>.
+## Copyright (C) 2007 Michael Creel <michael.creel@uab.es>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
-# kernel_example: examples of how to use kernel density and regression functions
-# requires the optim and plot packages from Octave Forge
-#
-# usage: kernel_example;
+## kernel_example: examples of how to use kernel density and regression functions
+## requires the optim and plot packages from Octave Forge
+##
+## usage: kernel_example;
 
 # sample size (default n = 500) - should get better fit (on average)
 # as this increases, supposing that you allow the optimal window width
@@ -61,7 +61,7 @@ bandwidth = 0.55;
 # bandwidth = kernel_optimal_bandwidth(data);
 # get the fitted density and do a plot
 tic;
-dens = kernel_density(grid_x, data, bandwidth, "__kernel_normal", false, false, compute_nodes);
+dens = kernel_density(grid_x, data, bandwidth, "kernel_normal", false, false, compute_nodes);
 t1 = toc;
 printf("\n");
 printf("########################################################################\n");
@@ -90,7 +90,7 @@ bandwidth = 0.85;
 # bandwidth = kernel_optimal_bandwidth(data);
 # get the fitted density and do a plot
 tic;
-dens = kernel_density(eval_points, data, bandwidth, "__kernel_normal", false, false, compute_nodes);
+dens = kernel_density(eval_points, data, bandwidth, "kernel_normal", false, false, compute_nodes);
 t1 = toc;
 printf("\n");
 printf("########################################################################\n");
@@ -109,7 +109,7 @@ if compute_nodes > 0 # only try this if parallel is available
 	printf("########################################################################\n");
 	printf("kernel regression example with several sample sizes serial/parallel timings\n");
 	figure();
-	clg;
+	clf;
 	title("Compute time versus nodes, kernel regression with different sample sizes");
 	xlabel("nodes");
 	ylabel("time (sec)");
@@ -128,7 +128,7 @@ if compute_nodes > 0 # only try this if parallel is available
 			y = trueline + sig*randn(n,1);
 			bandwidth = 0.45;
 			tic;
-			fit = kernel_regression(x, y, x, bandwidth, "__kernel_normal", false, false, compute_nodes);
+			fit = kernel_regression(x, y, x, bandwidth, "kernel_normal", false, false, compute_nodes);
 			t1 = toc;
 			ts(i, nodes) = t1;
 			plot(nodes, t1, "*");
